<?php
/**
 * Ce fichier contient les autorisations nécessaire à la gestion de l'archivage des objets.
 *
 * @package SPIP\ARCHOBJET\AUTORISATIONS
 */
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}
/**
 * Fonction vide pour le pipeline homonyme.
 *
 * @return void
 */
function archobjet_autoriser() {}

/**
 * Autorisation de base pour l'archivage d'un type de contenu.
 * - l'objet doit être archivable
 * - et l'utilisateur doit être un administrateur même restreint.
 *
 * @param string $faire
 *   une action ('modifier', 'publier'...)
 * @param string|null $type
 *   Type d’objet ou élément sur lequel appliquer l’action.
 *   - null: indifférent à tout type d’élément ou objet éditorial
 *   - string: objet éditorial (objet_type() est appliqué pour homogénéiser l’entrée)
 *   - _string: autre élément (avec un souligné en premier caractère, désactive objet_type()).
 *   Les soulignés seront retirés (cf. la note).
 * @param string|int|null $id
 *   id de l'objet ou élément sur lequel on veut agir, si pertinent.
 *   - null: non utile pour l’autorisation
 *   - int: identifiant numérique (cas de tous les objets éditoriaux de SPIP)
 *   - string: identifiant textuel
 * @param null|int|array<mixed> $qui
 *   - si null on prend alors visiteur_session
 *   - un id_auteur (on regarde dans la base)
 *   - un tableau auteur complet, y compris [restreint]
 * @param array<mixed> $options
 *   options sous forme de tableau associatif
 *
 * @return bool true s'il a le droit, false sinon
**/
function autoriser_archivage_dist($faire, $type, $id, $qui, $options) {
	$autoriser = false;

	if ($type) {
		// Lecture des tables autorisées à l'archivage
		include_spip('inc/config');
		$tables_autorisees = lire_config('archobjet/objets_archivables', array());

		// Rechercher
		include_spip('base/objets');
		$table = table_objet_sql($type);

		// Si l'objet est archivable et que l'utilisateur est un administrateur non restreint on autorise
		// l'archivage.
		if (
			in_array($table, $tables_autorisees)
			and ($qui['statut'] == '0minirezo')
		) {
			$autoriser = true;
		}
	}

	return $autoriser;
}

/**
 * Autorisation d'archiver l'objet concerné.
 * - l'archivage doit être autorisé sur le type d'objet
 * - et l'objet non déjà archivé.
 *
 * @param string $faire
 *   une action ('modifier', 'publier'...)
 * @param string|null $type
 *   Type d’objet ou élément sur lequel appliquer l’action.
 *   - null: indifférent à tout type d’élément ou objet éditorial
 *   - string: objet éditorial (objet_type() est appliqué pour homogénéiser l’entrée)
 *   - _string: autre élément (avec un souligné en premier caractère, désactive objet_type()).
 *   Les soulignés seront retirés (cf. la note).
 * @param string|int|null $id
 *   id de l'objet ou élément sur lequel on veut agir, si pertinent.
 *   - null: non utile pour l’autorisation
 *   - int: identifiant numérique (cas de tous les objets éditoriaux de SPIP)
 *   - string: identifiant textuel
 * @param null|int|array<mixed> $qui
 *   - si null on prend alors visiteur_session
 *   - un id_auteur (on regarde dans la base)
 *   - un tableau auteur complet, y compris [restreint]
 * @param array<mixed> $options
 *   options sous forme de tableau associatif
 *
 * @return bool true s'il a le droit, false sinon
**/
function autoriser_modifierarchivage_dist($faire, $type, $id, $qui, $options) {
	$autoriser = false;

	if (
		autoriser('archivage', $type)
		and $type
		and ($id_objet = intval($id))
		and ($action = $options['action'])
	) {
		// Vérification de l'état d'archivage
		include_spip('inc/archobjet');
		$etat_archivage = archivage_lire_etat_objet(
			$type,
			$id_objet
		);
		if (
			(
				($action == 'archiver')
				and !$etat_archivage['est_archive']
			)
			or (
				($action == 'desarchiver')
				and $etat_archivage['est_archive']
			)
			or ($action == 'modifier_raison')
		) {
			$autoriser = true;
		}
	}

	return $autoriser;
}
